@@ -14,12 +14,11 @@ from __future__ import absolute_import, division, unicode_literals
 import time
 
 from mo_future import allocate_lock
-from mo_imports import expect
+
+from mo_logs import Log
 from mo_logs.log_usingNothing import StructuredLogger
 from mo_logs.strings import expand_template
 
-Log = expect("Log")
-
 
 class StructuredLogger_usingFile(StructuredLogger):
     def __init__(self, file):
@@ -38,6 +37,9 @@ class StructuredLogger_usingFile(StructuredLogger):
             with self.file_lock:
                 self.file.append(expand_template(template, params))
         except Exception as e:
-            Log.warning("Problem writing to file {{file}}, waiting...", file=self.file.name, cause=e)
+            Log.warning(
+                "Problem writing to file {{file}}, waiting...",
+                file=self.file.name,
+                cause=e,
+            )
             time.sleep(5)
-
